image-diet2
===========

image-diet2 is a Django application for removing unnecessary bytes from image
files.  It optimizes images without changing their look or visual quality
("losslessly").

It works on images in JPEG, GIF, PNG or any format with configured a
processing pipeline. Integration with Django's storage system provides a
seamless integration with most thumbnailing apps.


**Documentation:**

.. image:: https://readthedocs.org/projects/image-diet2/badge/?version=latest
  :target: http://image-diet2.readthedocs.org/en/latest/?badge=latest
  :alt: Documentation Status

**Tests:**

.. image:: https://coveralls.io/repos/samastur/image-diet2/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/samastur/image-diet2?branch=master 

.. image:: https://travis-ci.org/samastur/image-diet2.svg?branch=master
  :target: https://travis-ci.org/samastur/image-diet2

**Build:**

.. image:: https://requires.io/github/samastur/image-diet2/requirements.svg?branch=master
  :target: https://requires.io/github/samastur/image-diet2/requirements/?branch=master
  :alt: Requirements Status

`Documentation <http://image-diet2.readthedocs.org/en/latest/>`_
